@@ -502,6 +502,7 @@ tp_process_trackpoint_button(struct tp_dispatch *tp,
 {
 	struct evdev_dispatch *dispatch;
 	struct input_event event;
+	struct input_event syn_report = {{ 0, 0 }, EV_SYN, SYN_REPORT, 0 };
 
 	if (!tp->buttons.trackpoint)
 		return;
@@ -509,6 +510,7 @@ tp_process_trackpoint_button(struct tp_dispatch *tp,
 	dispatch = tp->buttons.trackpoint->dispatch;
 
 	event = *e;
+	syn_report.time = e->time;
 
 	switch (event.code) {
 	case BTN_0:
@@ -527,6 +529,9 @@ tp_process_trackpoint_button(struct tp_dispatch *tp,
 	dispatch->interface->process(dispatch,
 				     tp->buttons.trackpoint,
 				     &event, time);
+	dispatch->interface->process(dispatch,
+				     tp->buttons.trackpoint,
+				     &syn_report, time);
 }
 
 static void
