@@ -83,8 +83,6 @@ path_seat_create(struct path_input *input,
 	struct path_seat *seat;
 
 	seat = zalloc(sizeof(*seat));
-	if (!seat)
-		return NULL;
 
 	libinput_seat_init(&seat->base, &input->base, seat_name,
 			   seat_logical_name, path_seat_destroy);
@@ -123,10 +121,10 @@ path_device_enable(struct path_input *input,
 	sysname = udev_device_get_sysname(udev_device);
 
 	seat_prop = udev_device_get_property_value(udev_device, "ID_SEAT");
-	seat_name = strdup(seat_prop ? seat_prop : default_seat);
+	seat_name = safe_strdup(seat_prop ? seat_prop : default_seat);
 
 	if (seat_logical_name_override) {
-		seat_logical_name = strdup(seat_logical_name_override);
+		seat_logical_name = safe_strdup(seat_logical_name_override);
 	} else {
 		seat_prop = udev_device_get_property_value(udev_device, "WL_SEAT");
 		seat_logical_name = strdup(seat_prop ? seat_prop : default_seat_name);
@@ -175,8 +173,7 @@ path_device_enable(struct path_input *input,
 
 	evdev_read_calibration_prop(device);
 	output_name = udev_device_get_property_value(udev_device, "WL_OUTPUT");
-	if (output_name)
-		device->output_name = strdup(output_name);
+	device->output_name = safe_strdup(output_name);
 
 out:
 	free(seat_name);
@@ -226,9 +223,6 @@ path_create_device(struct libinput *libinput,
 	struct libinput_device *device;
 
 	dev = zalloc(sizeof *dev);
-	if (!dev)
-		return NULL;
-
 	dev->udev_device = udev_device_ref(udev_device);
 
 	list_insert(&input->path_list, &dev->link);
@@ -285,8 +279,7 @@ libinput_path_create_context(const struct libinput_interface *interface,
 		return NULL;
 
 	input = zalloc(sizeof *input);
-	if (!input ||
-	    libinput_init(&input->base, interface,
+	if (libinput_init(&input->base, interface,
 			  &interface_backend, user_data) != 0) {
 		udev_unref(udev);
 		free(input);
